@@ -404,6 +404,10 @@ func replace(new slog.Value, keys ...string) func([]string, slog.Attr) slog.Attr
 }
 
 func TestReplaceAttr(t *testing.T) {
+	if !faketime.Equal(time.Now()) {
+		t.Skip(`skipping test; run with "-tags=faketime"`)
+	}
+
 	tests := [][]any{
 		{},
 		{"key", "val"},
@@ -554,6 +558,14 @@ func BenchmarkLogAttrs(b *testing.B) {
 				)
 			},
 		},
+		{
+			"error",
+			func(logger *slog.Logger) {
+				logger.LogAttrs(context.TODO(), slog.LevelError, testMessage,
+					tint.Err(errTest),
+				)
+			},
+		},
 	}
 
 	for _, h := range handler {
